[Bf-blender-cvs] [48b4d42bce2] master: CMake: Fix WITH_CODEC_SNDFILE detection

Campbell Barton noreply at git.blender.org
Fri Jul 19 01:39:44 CEST 2019


Commit: 48b4d42bce2f94e486af9a51d7b6ec1126b7dc29
Author: Campbell Barton
Date:   Fri Jul 19 09:14:15 2019 +1000
Branches: master
https://developer.blender.org/rB48b4d42bce2f94e486af9a51d7b6ec1126b7dc29

CMake: Fix WITH_CODEC_SNDFILE detection

D5296 by @frispete

===================================================================

M	build_files/cmake/Modules/FindSndFile.cmake
M	build_files/cmake/platform/platform_unix.cmake

===================================================================

diff --git a/build_files/cmake/platform/platform_unix.cmake b/build_files/cmake/platform/platform_unix.cmake
index 0f5b45d722b..43d13a97a3e 100644
--- a/build_files/cmake/platform/platform_unix.cmake
+++ b/build_files/cmake/platform/platform_unix.cmake
@@ -156,7 +156,7 @@ endif()
 # Codecs
 if(WITH_CODEC_SNDFILE)
   find_package_wrapper(SndFile)
-  if(NOT LIBSNDFILE_FOUND)
+  if(NOT SNDFILE_FOUND)
     set(WITH_CODEC_SNDFILE OFF)
   endif()
 endif()



More information about the Bf-blender-cvs mailing list
diff --git a/build_files/cmake/Modules/FindSndFile.cmake b/build_files/cmake/Modules/FindSndFile.cmake
index eabc08b0645..a520a45e370 100644
--- a/build_files/cmake/Modules/FindSndFile.cmake
+++ b/build_files/cmake/Modules/FindSndFile.cmake
@@ -6,7 +6,7 @@
 #  LIBSNDFILE_LIBRARIES, libraries to link against to use SndFile.
 #  LIBSNDFILE_ROOT_DIR, The base directory to search for SndFile.
 #                    This can also be an environment variable.
 #  LIBSNDFILE_FOUND, If false, do not try to use SndFile.
 #
 # also defined, but not for general use are
 #  LIBSNDFILE_LIBRARY, where to find the SndFile library.
@@ -50,16 +50,16 @@ FIND_LIBRARY(LIBSNDFILE_LIBRARY
     lib64 lib
   )
 
 # handle the QUIETLY and REQUIRED arguments and set LIBSNDFILE_FOUND to TRUE if
 # all listed variables are TRUE
 INCLUDE(FindPackageHandleStandardArgs)
 FIND_PACKAGE_HANDLE_STANDARD_ARGS(SndFile DEFAULT_MSG
   LIBSNDFILE_LIBRARY LIBSNDFILE_INCLUDE_DIR)
 
-IF(LIBSNDFILE_FOUND)
+IF(SNDFILE_FOUND)
   SET(LIBSNDFILE_LIBRARIES ${LIBSNDFILE_LIBRARY})
   SET(LIBSNDFILE_INCLUDE_DIRS ${LIBSNDFILE_INCLUDE_DIR})
-ENDIF(LIBSNDFILE_FOUND)
+ENDIF(SNDFILE_FOUND)
 
 MARK_AS_ADVANCED(
   LIBSNDFILE_INCLUDE_DIR
@@ -6,7 +6,7 @@
 #  LIBSNDFILE_ROOT_DIR, The base directory to search for SndFile.
 #                    This can also be an environment variable.
-#  LIBSNDFILE_FOUND, If false, do not try to use SndFile.
+#  SNDFILE_FOUND, If false, do not try to use SndFile.
 #
 # also defined, but not for general use are
@@ -50,16 +50,16 @@ FIND_LIBRARY(LIBSNDFILE_LIBRARY
   )
 
-# handle the QUIETLY and REQUIRED arguments and set LIBSNDFILE_FOUND to TRUE if
+# handle the QUIETLY and REQUIRED arguments and set SNDFILE_FOUND to TRUE if
 # all listed variables are TRUE
 INCLUDE(FindPackageHandleStandardArgs)